==> fdroidserver-2.2.2.arm64_monterey.bottle.tar.gz: fdroidserver/2.2.2/libexec/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"@@HOMEBREW_CELLAR@@/fdroidserver/2.2.2/libexec/bin/python",

        # Package versions
        contourpy_version="1.2.1",
        meson_version="1.4.0",
        mesonpy_version="0.16.0",
        pybind11_version="2.12.0",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/private/tmp/fdroidserver--contourpy-20240424-12338-wfh7rl/contourpy-1.2.1/.mesonpy-abkao3xj/lib/contourpy/util",
        source_dir=r"/private/tmp/fdroidserver--contourpy-20240424-12338-wfh7rl/contourpy-1.2.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/private/tmp/fdroidserver--contourpy-20240424-12338-wfh7rl/contourpy-1.2.1/.mesonpy-abkao3xj/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="14.0.0",
        linker_id="ld64",
        compile_command="clang++",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="aarch64",
        build_cpu_family="aarch64",
        build_cpu_endian="little",
        build_cpu_system="darwin",
    )

==> fdroidserver-2.2.2_2.arm64_monterey.bottle.tar.gz: fdroidserver/2.2.2_2/libexec/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"@@HOMEBREW_CELLAR@@/fdroidserver/2.2.2_2/libexec/bin/python",

        # Package versions
        contourpy_version="1.2.1",
        meson_version="1.4.1",
        mesonpy_version="0.16.0",
        pybind11_version="2.12.0",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/private/tmp/fdroidserver--contourpy-20240618-17621-pqlkhf/contourpy-1.2.1/.mesonpy-umw63cc5/lib/contourpy/util",
        source_dir=r"/private/tmp/fdroidserver--contourpy-20240618-17621-pqlkhf/contourpy-1.2.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/private/tmp/fdroidserver--contourpy-20240618-17621-pqlkhf/contourpy-1.2.1/.mesonpy-umw63cc5/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="14.0.0",
        linker_id="ld64",
        compile_command="clang++",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="aarch64",
        build_cpu_family="aarch64",
        build_cpu_endian="little",
        build_cpu_system="darwin",
    )
